@@ -1,4 +1,4 @@
-/* $Id: name_identifier_mapping.h 3237 2007-05-30 17:17:45Z dlaniel $ 
+/* $Id: name_identifier_mapping.h 3450 2007-11-22 14:46:42Z fpeters $ 
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
@@ -81,7 +81,7 @@ LASSO_EXPORT void lasso_name_identifier_mapping_destroy(
 
 LASSO_EXPORT gint lasso_name_identifier_mapping_init_request(
 		LassoNameIdentifierMapping *mapping,
-		gchar *targetNameSpace, gchar *remote_providerID);
+		gchar *targetNamespace, gchar *remote_providerID);
 
 LASSO_EXPORT gint lasso_name_identifier_mapping_process_request_msg(
 		LassoNameIdentifierMapping *mapping, gchar *request_msg); 
