@@ -1,4 +1,4 @@
-/* $Id: provider.c 3291 2007-06-12 14:14:57Z dlaniel $
+/* $Id: provider.c 3704 2008-05-15 21:17:44Z fpeters $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
@@ -22,6 +22,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+/**
+ * SECTION:provider
+ * @short_description: Service or identity provider
+ *
+ * It holds all the data about a provider.
+ **/
+
 #include <libxml/xpath.h>
 #include <libxml/xpathInternals.h>
 
@@ -76,6 +83,7 @@ lasso_provider_get_assertion_consumer_service_url(LassoProvider *provider, const
 	char *sid = (char*)service_id;
 	char *name;
 
+        g_return_val_if_fail(LASSO_IS_PROVIDER(provider), NULL);
 	if (sid == NULL)
 		sid = provider->private_data->default_assertion_consumer;
 
@@ -108,6 +116,7 @@ lasso_provider_get_metadata_one(LassoProvider *provider, const char *name)
 	GList *l;
 	GHashTable *descriptor;
 
+        g_return_val_if_fail(LASSO_IS_PROVIDER(provider), NULL);
 	descriptor = provider->private_data->SPDescriptor; /* default to SP */
 	if (provider->role == LASSO_PROVIDER_ROLE_IDP)
 		descriptor = provider->private_data->IDPDescriptor;
@@ -138,6 +147,7 @@ lasso_provider_get_metadata_list(LassoProvider *provider, const char *name)
 {
 	GHashTable *descriptor;
 
+        g_return_val_if_fail(LASSO_IS_PROVIDER(provider), NULL);
 	descriptor = provider->private_data->SPDescriptor; /* default to SP */
 	if (provider->role == LASSO_PROVIDER_ROLE_IDP)
 		descriptor = provider->private_data->IDPDescriptor;
@@ -167,6 +177,7 @@ lasso_provider_get_first_http_method(LassoProvider *provider,
 	GList *t1, *t2 = NULL;
 	gboolean found;
 
+        g_return_val_if_fail(LASSO_IS_PROVIDER(provider), LASSO_HTTP_METHOD_NONE);
 	if (provider->private_data->conformance == LASSO_PROTOCOL_SAML_2_0) {
 		return lasso_saml20_provider_get_first_http_method(
 				provider, remote_provider, protocol_type);
@@ -234,6 +245,7 @@ lasso_provider_accept_http_method(LassoProvider *provider, LassoProvider *remote
 	LassoProviderRole initiating_role;
 	char *protocol_profile;
 
+        g_return_val_if_fail(LASSO_IS_PROVIDER(provider), FALSE); // Be conservative
 	if (provider->private_data->conformance == LASSO_PROTOCOL_SAML_2_0) {
 		return lasso_saml20_provider_accept_http_method(
 				provider, remote_provider, protocol_type,
@@ -288,6 +300,7 @@ lasso_provider_has_protocol_profile(LassoProvider *provider,
 {
 	GList *supported;
 	
+        g_return_val_if_fail(LASSO_IS_PROVIDER(provider), FALSE); // Be conservative
 	supported = lasso_provider_get_metadata_list(
 			provider, protocol_md_nodename[protocol_type]);
 	
@@ -310,6 +323,7 @@ lasso_provider_get_base64_succinct_id(LassoProvider *provider)
 {
 	char *succinct_id, *base64_succinct_id;
 
+        g_return_val_if_fail(LASSO_IS_PROVIDER(provider), NULL);
 	succinct_id = lasso_sha1(provider->ProviderID);
 	base64_succinct_id = (char*)xmlSecBase64Encode((xmlChar*)succinct_id, 20, 0);
 	xmlFree(succinct_id);
@@ -329,6 +343,7 @@ lasso_provider_get_base64_succinct_id(LassoProvider *provider)
 xmlNode*
 lasso_provider_get_organization(LassoProvider *provider)
 {
+        g_return_val_if_fail(LASSO_IS_PROVIDER(provider), NULL);
 	if (provider->private_data->organization) {
 		return xmlCopyNode(provider->private_data->organization, 1);
 	} else {
@@ -354,6 +369,7 @@ static LassoNodeClass *parent_class = NULL;
 xmlSecKey*
 lasso_provider_get_public_key(LassoProvider *provider)
 {
+        g_return_val_if_fail(LASSO_IS_PROVIDER(provider), NULL);
 	return provider->private_data->public_key;
 }
 
@@ -364,6 +380,7 @@ load_descriptor(xmlNode *xmlnode, GHashTable *descriptor, LassoProvider *provide
 	GList *elements;
 	char *name;
 	xmlChar *value;
+	xmlChar *use;
 
 	t = xmlnode->children;
 	while (t) {
@@ -372,10 +389,14 @@ load_descriptor(xmlNode *xmlnode, GHashTable *descriptor, LassoProvider *provide
 			continue;
 		}
 		if (strcmp((char*)t->name, "KeyDescriptor") == 0) {
-			xmlChar *use = xmlGetProp(t, (xmlChar*)"use");
+			use = xmlGetProp(t, (xmlChar*)"use");
 			if (use && strcmp((char*)use, "signing") == 0) {
 				provider->private_data->signing_key_descriptor = xmlCopyNode(t, 1);
 			}
+			if (use && strcmp((char*)use, "encryption") == 0) {
+				provider->private_data->encryption_key_descriptor = 
+					xmlCopyNode(t, 1);
+			}
 			if (use) {
 				xmlFree(use);
 			}
@@ -650,6 +671,7 @@ lasso_provider_get_type()
 LassoProtocolConformance
 lasso_provider_get_protocol_conformance(LassoProvider *provider)
 {
+        g_return_val_if_fail(LASSO_IS_PROVIDER(provider), LASSO_PROTOCOL_NONE);
 	return provider->private_data->conformance;
 }
 
@@ -664,6 +686,7 @@ lasso_provider_load_metadata(LassoProvider *provider, const gchar *metadata)
 	const char *xpath_sp = "/md:EntityDescriptor/md:SPDescriptor";
 	const char *xpath_organization = "/md:EntityDescriptor/md:Organization";
 
+        g_return_val_if_fail(LASSO_IS_PROVIDER(provider), FALSE);
 	doc = xmlParseFile(metadata);
 	if (doc == NULL)
 		return FALSE;
@@ -820,6 +843,7 @@ lasso_provider_load_public_key(LassoProvider *provider, LassoPublicKeyType publi
 	};
 	int i;
 
+        g_return_val_if_fail(LASSO_IS_PROVIDER(provider), FALSE);
 	if (public_key_type == LASSO_PUBLIC_KEY_SIGNING) {
 		public_key = provider->public_key;
 		key_descriptor = provider->private_data->signing_key_descriptor;
@@ -943,7 +967,8 @@ lasso_provider_new_from_dump(const gchar *dump)
 	return provider;
 }
 
-int lasso_provider_verify_signature(LassoProvider *provider,
+int 
+lasso_provider_verify_signature(LassoProvider *provider,
 		const char *message, const char *id_attr_name, LassoMessageFormat format)
 {
 	/* this duplicates some code from lasso_node_init_from_message;
@@ -958,9 +983,9 @@ int lasso_provider_verify_signature(LassoProvider *provider,
 	xmlXPathContext *xpathCtx = NULL;
 	xmlXPathObject *xpathObj = NULL;
 
+        g_return_val_if_fail(LASSO_IS_PROVIDER(provider), LASSO_PARAM_ERROR_BAD_TYPE_OR_NULL_OBJ);
 
 	msg = (char*)message;
-
 	if (message == NULL)
 		return LASSO_PROFILE_ERROR_INVALID_MSG;
 
@@ -1100,13 +1125,14 @@ int lasso_provider_verify_signature(LassoProvider *provider,
 /**
  * lasso_provider_set_encryption_mode:
  * @provider: provider to set encryption for
- * @encryption_activation: TRUE to activate, FALSE, to desactivate
+ * @encryption_mode: TRUE to activate, FALSE to desactivate
  *
  * Activate or desactivate encryption
  **/
 void
 lasso_provider_set_encryption_mode(LassoProvider *provider, LassoEncryptionMode encryption_mode)
 {
+        g_return_if_fail(LASSO_IS_PROVIDER(provider));
 	provider->private_data->encryption_mode = encryption_mode;
 }
 
@@ -1121,5 +1147,6 @@ void
 lasso_provider_set_encryption_sym_key_type(LassoProvider *provider,
 		LassoEncryptionSymKeyType encryption_sym_key_type)
 {
+        g_return_if_fail(LASSO_IS_PROVIDER(provider));
 	provider->private_data->encryption_sym_key_type = encryption_sym_key_type;
 }
