@@ -1,4 +1,4 @@
-/* $Id: server.c 3374 2007-08-12 22:19:32Z fpeters $
+/* $Id: server.c 3723 2008-05-21 12:35:54Z dlaniel $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
@@ -22,6 +22,14 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+/**
+ * SECTION:server
+ * @short_description: Representation of the current server
+ *
+ * It holds the data about a provider, other providers it knows, which
+ * certificates to use, etc.
+ **/
+
 #include <xmlsec/base64.h>
 
 #include <lasso/lasso_config.h>
@@ -121,12 +129,17 @@ gint
 lasso_server_add_service_from_dump(LassoServer *server, const gchar *dump)
 {
 	LassoNode *node;
+	gint return_code;
 
 	g_return_val_if_fail(dump != NULL, LASSO_PARAM_ERROR_INVALID_VALUE);
 
 	node = lasso_node_new_from_dump(dump);
 
-	return lasso_server_add_service(server, node);
+	return_code = lasso_server_add_service(server, node);
+
+	g_object_unref(node);
+
+	return return_code;
 }
 
 #ifdef LASSO_WSF_ENABLED
@@ -144,7 +157,7 @@ lasso_server_add_svc_metadata(LassoServer *server, LassoIdWsf2DiscoSvcMetadata *
 	return 0;
 }
 
-GList *
+const GList *
 lasso_server_get_svc_metadatas(LassoServer *server)
 {
 	g_return_val_if_fail(LASSO_IS_SERVER(server), NULL);
@@ -152,6 +165,7 @@ lasso_server_get_svc_metadatas(LassoServer *server)
 	return server->private_data->svc_metadatas;
 }
 
+/* XXX: return value must be freed by caller */
 GList *
 lasso_server_get_svc_metadatas_with_id_and_type(LassoServer *server, GList *svcMDIDs,
 	const gchar *service_type)
@@ -571,6 +585,7 @@ dispose(GObject *object)
 /* 	} */
 
 	if (server->private_data->svc_metadatas != NULL) {
+		g_list_foreach(server->private_data->svc_metadatas, (GFunc)g_object_unref, NULL);
 		g_list_free(server->private_data->svc_metadatas);
 		server->private_data->svc_metadatas = NULL;
 	}
@@ -672,10 +687,10 @@ lasso_server_get_type()
 
 /**
  * lasso_server_new:
- * @metadata: path to the provider metadata file
+ * @metadata: path to the provider metadata file or NULL, for a LECP server
  * @private_key: path to the the server private key file or NULL
- * @private_key_password: password to private key (if it is encrypted)
- * @certificate: path to the server certificate file
+ * @private_key_password: password to private key if it is encrypted, or NULL
+ * @certificate: path to the server certificate file, or NULL
  * 
  * Creates a new #LassoServer.
  * 
