@@ -1,4 +1,4 @@
-/* $Id: session.c 3342 2007-07-10 08:50:56Z fpeters $
+/* $Id: session.c 3725 2008-05-21 17:28:44Z dlaniel $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
@@ -22,6 +22,12 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+/**
+ * SECTION:session
+ * @short_description: Principal Session
+ *
+ **/
+
 #include <lasso/id-ff/session.h>
 #include <lasso/id-ff/sessionprivate.h>
 
@@ -63,7 +69,8 @@ lasso_session_add_assertion(LassoSession *session, char *providerID, LassoNode *
 	g_return_val_if_fail(providerID != NULL, LASSO_PARAM_ERROR_INVALID_VALUE);
 	g_return_val_if_fail(assertion != NULL, LASSO_PARAM_ERROR_INVALID_VALUE);
 
-	g_hash_table_insert(session->assertions, g_strdup(providerID), assertion);
+	g_hash_table_insert(session->assertions, g_strdup(providerID),
+			g_object_ref(assertion));
 
 	session->is_dirty = TRUE;
 
@@ -505,6 +512,7 @@ init_from_xml(LassoNode *node, xmlNode *xmlnode)
 					lasso_wsa_endpoint_reference_new());
 				LASSO_NODE_GET_CLASS(epr)->init_from_xml(LASSO_NODE(epr), t2);
 				lasso_session_add_endpoint_reference(session, epr);
+				g_object_unref(epr);
 				t2 = t2->next;
 			}
 		}
