@@ -47,6 +47,12 @@ struct _LassoIdWsf2DataServicePrivate
 	GList *credentials;
 };
 
+extern GHashTable *idwsf2_dst_services_by_prefix; /* cf xml/xml.c */
+
+static void lasso_register_idwsf2_xpath_namespaces(xmlXPathContext *xpathCtx);
+
+static GList* duplicate_glist_of_xmlnodes(GList*);
+
 /*****************************************************************************/
 /* public methods                                                            */
 /*****************************************************************************/
@@ -96,7 +102,7 @@ lasso_idwsf2_data_service_init_query(LassoIdWsf2DataService *service)
 			query->hrefServiceType);
 	}
 	if (query->prefixServiceType == NULL) {
-		return LASSO_PROFILE_ERROR_MISSING_SERVICE_TYPE;
+		return LASSO_DATA_SERVICE_ERROR_UNREGISTERED_DST;
 	}
 
 	lasso_idwsf2_profile_init_soap_request(profile, LASSO_NODE(query), service_type);
@@ -190,7 +196,9 @@ lasso_idwsf2_data_service_parse_query_items(LassoIdWsf2DataService *service)
 	LassoIdWsf2DstRefItemData *data_item;
 	xmlNode *node;
 	GList *iter;
-	int res = 0;
+	int i;
+	/* Default is Failed, will be OK or Partial when some items are successfully parsed */
+	char *status_code = LASSO_DST_STATUS_CODE_FAILED;
 
 	g_return_val_if_fail(LASSO_IS_IDWSF2_DATA_SERVICE(service),
 		LASSO_PARAM_ERROR_BAD_TYPE_OR_NULL_OBJ);
@@ -215,17 +223,11 @@ lasso_idwsf2_data_service_parse_query_items(LassoIdWsf2DataService *service)
 	LASSO_PROFILE(profile)->response = LASSO_NODE(response);
 	envelope->Body->any = g_list_append(envelope->Body->any, response);
 
-	response2 = LASSO_IDWSF2_UTIL_RESPONSE(response);
-	/* Default is Failed, will be OK or Partial when some items are successfully parsed */
-	response2->Status = lasso_idwsf2_util_status_new();
-	response2->Status->code = g_strdup(LASSO_DST_STATUS_CODE_FAILED);
-
 	/* Initialise XML parsing */
 	doc = xmlNewDoc((xmlChar*)"1.0");
 	xmlDocSetRootElement(doc, service->data);
 	xpathCtx = xmlXPathNewContext(doc);
-	xmlXPathRegisterNs(xpathCtx, (xmlChar*)response->prefixServiceType,
-		(xmlChar*)response->hrefServiceType);
+	lasso_register_idwsf2_xpath_namespaces(xpathCtx);
 
 	/* Parse request QueryItems and fill response Data accordingly */
 	/* XXX: needs another level, since there may be more than one <dst:Query> */
@@ -236,30 +238,29 @@ lasso_idwsf2_data_service_parse_query_items(LassoIdWsf2DataService *service)
 		xpathObj = xmlXPathEvalExpression((xmlChar*)item_result_query->Select, xpathCtx);
 		if (xpathObj && xpathObj->nodesetval && xpathObj->nodesetval->nodeNr) {
 			/* XXX: assuming there is only one matching node */
-			node = xpathObj->nodesetval->nodeTab[0];
+			data = lasso_idwsf2_dstref_data_new();
+			data_item = LASSO_IDWSF2_DSTREF_ITEM_DATA(data);
+			for (i = 0; i < xpathObj->nodesetval->nodeNr; i++) {
+				node = xpathObj->nodesetval->nodeTab[i];
+				if (node->type == XML_ATTRIBUTE_NODE) {
+					LASSO_IDWSF2_DSTREF_APP_DATA(data_item)->any = g_list_append(
+						LASSO_IDWSF2_DSTREF_APP_DATA(data_item)->any,
+						xmlNewText(xmlGetProp(node->parent, node->name)));
+				} else {
+					LASSO_IDWSF2_DSTREF_APP_DATA(data_item)->any = g_list_append(
+						LASSO_IDWSF2_DSTREF_APP_DATA(data_item)->any, xmlCopyNode(node, 1));
+				}
+			}
+		} else if (xpathObj && xpathObj->type == XPATH_STRING) {
 			data = lasso_idwsf2_dstref_data_new();
 			data_item = LASSO_IDWSF2_DSTREF_ITEM_DATA(data);
 			LASSO_IDWSF2_DSTREF_APP_DATA(data_item)->any = g_list_append(
 					LASSO_IDWSF2_DSTREF_APP_DATA(data_item)->any,
-					xmlCopyNode(node, 1));
-			if (item_result_query_base->itemID != NULL) {
-				data_item->itemIDRef = g_strdup(item_result_query_base->itemID);
-			}
-			response->Data = g_list_append(response->Data, data);
-			/* Success : change status code to OK */
-			if (strcmp(response2->Status->code, LASSO_DST_STATUS_CODE_FAILED) == 0) {
-				g_free(response2->Status->code);
-				response2->Status->code = g_strdup(LASSO_DST_STATUS_CODE_OK);
-			}
-			xmlXPathFreeObject(xpathObj);
-			xpathObj = NULL;
+					xmlNewText(xpathObj->stringval));
 		} else {
-			/* If status was OK, change it to Partial */
-			if (strcmp(response2->Status->code, LASSO_DST_STATUS_CODE_OK) == 0) {
-				g_free(response2->Status->code);
-				response2->Status->code = g_strdup(LASSO_DST_STATUS_CODE_PARTIAL);
-			} else {
-				res = LASSO_DST_ERROR_QUERY_FAILED;
+			/* If status was OK, change it to Partial, else keep it Failed */
+			if (strcmp(status_code, LASSO_DST_STATUS_CODE_OK) == 0) {
+				status_code = LASSO_DST_STATUS_CODE_PARTIAL;
 			}
 			if (xpathObj != NULL) {
 				xmlXPathFreeObject(xpathObj);
@@ -268,6 +269,16 @@ lasso_idwsf2_data_service_parse_query_items(LassoIdWsf2DataService *service)
 			/* Stop processing at first error */
 			break;
 		}
+
+		/* Finish handling of a successful item parsing */
+		status_code = LASSO_DST_STATUS_CODE_OK;
+		if (item_result_query_base->itemID != NULL) {
+			data_item->itemIDRef = g_strdup(item_result_query_base->itemID);
+		}
+		response->Data = g_list_append(response->Data, data);
+
+		xmlXPathFreeObject(xpathObj);
+		xpathObj = NULL;
 	}
 
 	/* Free XML parsing objects */
@@ -275,11 +286,15 @@ lasso_idwsf2_data_service_parse_query_items(LassoIdWsf2DataService *service)
 	xmlXPathFreeContext(xpathCtx);
 	xmlFreeDoc(doc);
 
-	if (res == 0 && strcmp(response2->Status->code, LASSO_DST_STATUS_CODE_FAILED) == 0) {
-		res = LASSO_DST_ERROR_QUERY_FAILED;
+	response2 = LASSO_IDWSF2_UTIL_RESPONSE(response);
+	response2->Status = lasso_idwsf2_util_status_new();
+	response2->Status->code = g_strdup(status_code);
+
+	if (strcmp(status_code, LASSO_DST_STATUS_CODE_FAILED) == 0) {
+		return LASSO_DST_ERROR_QUERY_FAILED;
 	}
 
-	return res;
+	return 0;
 }
 
 static gint
@@ -363,6 +378,52 @@ lasso_idwsf2_data_service_process_query_response_msg(LassoIdWsf2DataService *ser
 	return 0;
 }
 
+
+GList*
+lasso_idwsf2_data_service_get_attribute_nodes(LassoIdWsf2DataService *service, const gchar *item_id)
+{
+	LassoIdWsf2Profile *profile = LASSO_IDWSF2_PROFILE(service);
+	LassoIdWsf2DstRefQueryResponse *response;
+	LassoIdWsf2DstRefAppData *data = NULL;
+	GList *iter;
+
+	g_return_val_if_fail(LASSO_IS_IDWSF2_DATA_SERVICE(service), NULL);
+
+	g_return_val_if_fail(LASSO_IS_IDWSF2_DSTREF_QUERY_RESPONSE(
+				LASSO_PROFILE(profile)->response), NULL);
+
+	response = LASSO_IDWSF2_DSTREF_QUERY_RESPONSE(LASSO_PROFILE(profile)->response);
+
+	/* If no item_id is given, return the first item */
+	if (item_id == NULL && response->Data != NULL && response->Data->data != NULL) {
+		data = LASSO_IDWSF2_DSTREF_APP_DATA(response->Data->data);
+		if (data->any != NULL && data->any->data != NULL) {
+			return duplicate_glist_of_xmlnodes(data->any);
+		}
+	}
+	if (item_id == NULL) {
+		return NULL;
+	}
+
+	/* Find the item which has the given item_id */
+	for (iter = g_list_first(response->Data); iter != NULL; iter = g_list_next(iter)) {
+		if (! LASSO_IS_IDWSF2_DSTREF_ITEM_DATA(iter->data)) {
+			continue;
+		}
+		if (strcmp(LASSO_IDWSF2_DSTREF_ITEM_DATA(iter->data)->itemIDRef, item_id) == 0) {
+			data = LASSO_IDWSF2_DSTREF_APP_DATA(iter->data);
+			break;
+		}
+	}
+
+	if (data == NULL || data->any == NULL || data->any->data == NULL) {
+		/* Item not found */
+		return NULL;
+	}
+
+	return duplicate_glist_of_xmlnodes(data->any);
+}
+
 xmlNode*
 lasso_idwsf2_data_service_get_attribute_node(LassoIdWsf2DataService *service, const gchar *item_id)
 {
@@ -409,6 +470,30 @@ lasso_idwsf2_data_service_get_attribute_node(LassoIdWsf2DataService *service, co
 	return xmlCopyNode(data->any->data, 1);
 }
 
+GList*
+lasso_idwsf2_data_service_get_attribute_strings(LassoIdWsf2DataService *service,
+	const gchar *item_id)
+{
+	GList *nodes = NULL;
+	xmlChar *xml_content = NULL;
+	GList *contents = NULL;
+	GList *iter;
+
+	g_return_val_if_fail(LASSO_IS_IDWSF2_DATA_SERVICE(service), NULL);
+
+	nodes = lasso_idwsf2_data_service_get_attribute_nodes(service, item_id);
+	for (iter = nodes; iter; iter = g_list_next(iter)) {
+		xml_content = xmlNodeGetContent(iter->data);
+		contents = g_list_append(contents, g_strdup((gchar*)xml_content));
+		xmlFree(xml_content);
+		xmlFreeNode(iter->data);
+	}
+
+	g_list_free(nodes);
+
+	return contents;
+}
+
 gchar*
 lasso_idwsf2_data_service_get_attribute_string(LassoIdWsf2DataService *service,
 	const gchar *item_id)
@@ -508,7 +593,7 @@ lasso_idwsf2_data_service_init_modify(LassoIdWsf2DataService *service)
 			modify->hrefServiceType);
 	}
 	if (modify->prefixServiceType == NULL) {
-		return LASSO_PROFILE_ERROR_MISSING_SERVICE_TYPE;
+		return LASSO_DATA_SERVICE_ERROR_UNREGISTERED_DST;
 	}
 
 	lasso_idwsf2_profile_init_soap_request(profile, LASSO_NODE(modify), service_type);
@@ -544,7 +629,7 @@ static void set_xml_string(xmlNode **xmlnode, const char* string)
 
 gint
 lasso_idwsf2_data_service_add_modify_item(LassoIdWsf2DataService *service, const gchar *item_xpath,
-	const gchar *item_id, const gchar *new_data, const gboolean overrideAllowed)
+	const gchar *item_id, const gchar *new_data, gboolean overrideAllowed)
 {
 	LassoIdWsf2Profile *profile = LASSO_IDWSF2_PROFILE(service);
 	LassoIdWsf2DstRefModify *modify;
@@ -694,8 +779,7 @@ lasso_idwsf2_data_service_parse_modify_items(LassoIdWsf2DataService *service)
 	cur_doc = xmlNewDoc((xmlChar*)"1.0");
 	xmlDocSetRootElement(cur_doc, cur_data);
 	cur_xpathCtx = xmlXPathNewContext(cur_doc);
-	xmlXPathRegisterNs(cur_xpathCtx, (xmlChar*)response->prefixServiceType,
-		(xmlChar*)response->hrefServiceType);
+	lasso_register_idwsf2_xpath_namespaces(cur_xpathCtx);
 
 	/* Parse request ModifyItems and modify user current data accordingly */
 	/* XXX: needs another level, since there may be more than one <dst:Modify> */
@@ -773,6 +857,35 @@ lasso_idwsf2_data_service_process_modify_response_msg(LassoIdWsf2DataService *se
 
 static LassoNodeClass *parent_class = NULL;
 
+static void
+register_xpath_namespace(gchar *prefix, gchar *href, xmlXPathContext *xpathCtx)
+{
+	xmlXPathRegisterNs(xpathCtx, (xmlChar*)prefix, (xmlChar*)href);
+}
+
+static void
+lasso_register_idwsf2_xpath_namespaces(xmlXPathContext *xpathCtx)
+{
+	if (idwsf2_dst_services_by_prefix == NULL)
+		return;
+	g_hash_table_foreach(idwsf2_dst_services_by_prefix,
+			(GHFunc)register_xpath_namespace, xpathCtx);
+}
+
+static GList*
+duplicate_glist_of_xmlnodes(GList *list)
+{
+	GList *r = NULL;
+	GList *t;
+
+	for (t = list; t; t = g_list_next(t)) {
+		r = g_list_append(r, xmlCopyNode(t->data, 1));
+	}
+
+	return r;
+}
+
+
 /*****************************************************************************/
 /* overrided parent class methods */
 /*****************************************************************************/
@@ -786,23 +899,20 @@ dispose(GObject *object)
 		return;
 	service->private_data->dispose_has_run = TRUE;
 
-	if (service->type != NULL) {
-		g_free(service->type);
-		service->type = NULL;
-	}
-	if (service->redirect_url != NULL) {
-		g_free(service->redirect_url);
-		service->redirect_url = NULL;
-	}
+	g_free(service->type);
+	service->type = NULL;
+
+	g_free(service->redirect_url);
+	service->redirect_url = NULL;
+
 	if (service->query_items != NULL) {
+		g_list_foreach(service->query_items, (GFunc)g_free, NULL);
 		g_list_free(service->query_items);
 		service->query_items = NULL;
 	}
 
-	if (service->private_data->epr != NULL) {
-		lasso_node_destroy(LASSO_NODE(service->private_data->epr));
-		service->private_data->epr = NULL;
-	}
+	lasso_node_destroy(LASSO_NODE(service->private_data->epr));
+	service->private_data->epr = NULL;
 
 	G_OBJECT_CLASS(parent_class)->dispose(object);
 }
@@ -830,6 +940,7 @@ instance_init(LassoIdWsf2DataService *service)
 	service->query_items = NULL;
 	service->private_data = g_new0(LassoIdWsf2DataServicePrivate, 1);
 	service->private_data->epr = NULL;
+	service->private_data->credentials = NULL;
 }
 
 static void
