@@ -1,4 +1,4 @@
-/* $Id: dst_data.h 3237 2007-05-30 17:17:45Z dlaniel $ 
+/* $Id: dst_data.h 3437 2007-11-03 21:23:50Z fpeters $ 
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
@@ -46,7 +46,7 @@ typedef struct _LassoDstDataClass LassoDstDataClass;
 struct _LassoDstData {
 	LassoNode parent;
 
-	GList *any; /* list of xmlNodes */
+	GList *any; /* list of xmlNode* */
 
 	char *id;
 	char *itemIDRef;
