@@ -1,8 +1,8 @@
-/* $Id: private.h,v 1.22 2006/12/16 09:47:15 fpeters Exp $ 
+/* $Id: private.h 3374 2007-08-12 22:19:32Z fpeters $ 
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
- * Copyright (C) 2004, 2005 Entr'ouvert
+ * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
  * 
  * Authors: See AUTHORS file in top-level directory.
@@ -54,6 +54,7 @@ typedef enum {
 	SNIPPET_OPTIONAL = 1 << 23, /* optional, ignored if 0 */
 	SNIPPET_OPTIONAL_NEG = 1 << 24, /* optional, ignored if -1 */
 	SNIPPET_ANY = 1 << 25, /* ##any node */
+	SNIPPET_ALLOW_TEXT = 1 << 26, /* allow text childs in list of nodes */
 } SnippetType;
 
 struct XmlSnippet {
@@ -118,12 +119,17 @@ int lasso_sign_node(xmlNode *xmlnode, const char *id_attr_name, const char *id_v
 
 void xmlCleanNs(xmlNode *root_node);
 
+void xml_insure_namespace(xmlNode *xmlnode, xmlNs *ns, gboolean force,
+		gchar *ns_href, gchar *ns_prefix);
+
 gchar* lasso_node_build_deflated_query(LassoNode *node);
 
 gboolean lasso_node_init_from_deflated_query_part(LassoNode *node, char *deflate_string);
 
 char* lasso_concat_url_query(char *url, char *query);
 
+xmlDocPtr lasso_xml_parse_memory(const char *buffer, int size);
+
 void _debug(GLogLevelFlags level, const char *filename, int line,
 		const char *function, const char *format, ...);
 
