@@ -1,4 +1,4 @@
-/* $Id: samlp2_attribute_query.c 3237 2007-05-30 17:17:45Z dlaniel $ 
+/* $Id: samlp2_attribute_query.c 3704 2008-05-15 21:17:44Z fpeters $ 
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
@@ -24,8 +24,12 @@
 
 #include "samlp2_attribute_query.h"
 
-/*
- * Schema fragment (saml-schema-protocol-2.0.xsd):
+/**
+ * SECTION:samlp2_attribute_query
+ * @short_description: &lt;samlp2:AttributeQuery&gt;
+ *
+ * <figure><title>Schema fragment for samlp2:AttributeQuery</title>
+ * <programlisting><![CDATA[
  *
  * <complexType name="AttributeQueryType">
  *   <complexContent>
@@ -36,6 +40,8 @@
  *     </extension>
  *   </complexContent>
  * </complexType>
+ * ]]></programlisting>
+ * </figure>
  */
 
 /*****************************************************************************/
@@ -44,7 +50,7 @@
 
 
 static struct XmlSnippet schema_snippets[] = {
-	{ "Attribute", SNIPPET_NODE,
+	{ "Attribute", SNIPPET_LIST_NODES ,
 		G_STRUCT_OFFSET(LassoSamlp2AttributeQuery, Attribute) },
 	{NULL, 0, 0}
 };
