@@ -1,4 +1,4 @@
-/* $Id: samlp2_request_abstract.c 3237 2007-05-30 17:17:45Z dlaniel $ 
+/* $Id: samlp2_request_abstract.c 3704 2008-05-15 21:17:44Z fpeters $ 
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
@@ -28,8 +28,12 @@
 
 #include "samlp2_request_abstract.h"
 
-/*
- * Schema fragment (saml-schema-protocol-2.0.xsd):
+/**
+ * SECTION:samlp2_request_abstract
+ * @short_description: &lt;samlp2:RequestAbstract&gt;
+ *
+ * <figure><title>Schema fragment for samlp2:RequestAbstract</title>
+ * <programlisting><![CDATA[
  *
  * <complexType name="RequestAbstractType" abstract="true">
  *   <sequence>
@@ -43,6 +47,8 @@
  *   <attribute name="Destination" type="anyURI" use="optional"/>
  *   <attribute name="Consent" type="anyURI" use="optional"/>
  * </complexType>
+ * ]]></programlisting>
+ * </figure>
  */
 
 /*****************************************************************************/
@@ -96,9 +102,14 @@ get_xmlNode(LassoNode *node, gboolean lasso_dump)
 	xmlnode = parent_class->get_xmlNode(node, lasso_dump);
 
 	if (lasso_dump == FALSE && request->sign_type) {
-		rc = lasso_sign_node(xmlnode, "ID", request->ID,
+		if (request->private_key_file == NULL) {
+			message(G_LOG_LEVEL_WARNING,
+					"No Private Key set for signing samlp2:RequestAbstract");
+		} else {
+			rc = lasso_sign_node(xmlnode, "ID", request->ID,
 				request->private_key_file, request->certificate_file);
-		/* signature may have failed; what to do ? */
+			/* signature may have failed; what to do ? */
+		}
 	}
 
 	return xmlnode;
