@@ -1,8 +1,8 @@
-/* $Id: saml_attribute_value.c,v 1.4 2006/10/09 10:09:25 fpeters Exp $
+/* $Id: saml_attribute_value.c 3237 2007-05-30 17:17:45Z dlaniel $
  *
- * Lasso - A free implementation of the Samlerty Alliance specifications.
+ * Lasso - A free implementation of the Liberty Alliance specifications.
  *
- * Copyright (C) 2004 Entr'ouvert
+ * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
  * 
  * Authors: Nicolas Clapies <nclapies@entrouvert.com>
@@ -35,7 +35,8 @@
 /*****************************************************************************/
 
 static struct XmlSnippet schema_snippets[] = {
-	{ "", SNIPPET_LIST_NODES, G_STRUCT_OFFSET(LassoSamlAttributeValue, any) },
+	{ "", SNIPPET_LIST_NODES | SNIPPET_ALLOW_TEXT,
+		G_STRUCT_OFFSET(LassoSamlAttributeValue, any) },
 	{ NULL, 0, 0 }
 };
 
