@@ -1,4 +1,4 @@
-/* $Id: soap_envelope.c 3237 2007-05-30 17:17:45Z dlaniel $ 
+/* $Id: soap_envelope.c 3715 2008-05-20 18:34:09Z dlaniel $ 
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
@@ -24,9 +24,10 @@
 
 #include <lasso/xml/soap_envelope.h>
 
-/*
- * Schema fragments ():
- * 
+/**
+ * SECTION:soap_envelope
+ * @short_description: &lt;soap:Envelope&gt;
+ *
  */ 
 
 /*****************************************************************************/
@@ -88,26 +89,23 @@ lasso_soap_envelope_get_type()
 LassoSoapEnvelope*
 lasso_soap_envelope_new(LassoSoapBody *body)
 {
-	LassoSoapEnvelope *node;
+	LassoSoapEnvelope *envelope;
 
-	node = g_object_new(LASSO_TYPE_SOAP_ENVELOPE, NULL);
+	envelope = g_object_new(LASSO_TYPE_SOAP_ENVELOPE, NULL);
 
-	node->Body = body;
+	envelope->Body = body;
 
-	return node;
+	return envelope;
 }
 
 LassoSoapEnvelope*
 lasso_soap_envelope_new_from_message(const gchar *message)
 {
-	LassoSoapEnvelope *node;
+	LassoSoapEnvelope *envelope;
 
 	g_return_val_if_fail(message != NULL, NULL);
 
-	node = g_object_new(LASSO_TYPE_SOAP_ENVELOPE, NULL);
-	lasso_node_init_from_message(LASSO_NODE(node), message);
+	envelope = LASSO_SOAP_ENVELOPE(lasso_node_new_from_dump(message));
 
-	node = LASSO_SOAP_ENVELOPE(lasso_node_new_from_dump(message));
-
-	return node;
+	return envelope;
 }
