@@ -1,4 +1,4 @@
-/* $Id: strings.h 3339 2007-07-06 18:47:55Z fpeters $ 
+/* $Id: strings.h 3704 2008-05-15 21:17:44Z fpeters $ 
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
@@ -22,6 +22,12 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+/**
+ * SECTION:strings
+ * @short_description: Useful string constants
+ *
+ **/
+
 #ifndef __LASSO_STRINGS_H__
 #define __LASSO_STRINGS_H__
 
@@ -50,9 +56,41 @@
 #define LASSO_LIB_MINOR_VERSION_N	 2
 
 /* NameIDPolicyType */
+
+/**
+ * LASSO_LIB_NAMEID_POLICY_TYPE_NONE:
+ *
+ * <emphasis>None</emphasis> policy for use in #LassoLibAuthnRequest.  It
+ * means an existing federation must be used and an error should be produced if
+ * none existed beforehand.
+ */
 #define LASSO_LIB_NAMEID_POLICY_TYPE_NONE	 "none"
+
+/**
+ * LASSO_LIB_NAMEID_POLICY_TYPE_ONE_TIME:
+ *
+ * <emphasis>Onetime</emphasis> policy for use in #LassoLibAuthnRequest.  It
+ * means a federation must not be created between identity and service
+ * provider.  A temporary name identifier should be used instead.
+ */
 #define LASSO_LIB_NAMEID_POLICY_TYPE_ONE_TIME	 "onetime"
+
+/**
+ * LASSO_LIB_NAMEID_POLICY_TYPE_FEDERATED:
+ *
+ * <emphasis>Federated</emphasis> policy for use in #LassoLibAuthnRequest.  It
+ * means a federation may be created between identity and service provider (if
+ * it didn't exist before).
+ */
 #define LASSO_LIB_NAMEID_POLICY_TYPE_FEDERATED	 "federated"
+
+/**
+ * LASSO_LIB_NAMEID_POLICY_TYPE_ANY:
+ *
+ * <emphasis>Any</emphasis> policy for use in #LassoLibAuthnRequest.  It means
+ * a federation may be created if the principal agrees and it can fall back to
+ * <emphasis>onetime</emphasis> if he does not.
+ */
 #define LASSO_LIB_NAMEID_POLICY_TYPE_ANY	 "any"
 
 /* AuthenticationClassRef */
@@ -104,10 +142,27 @@
 #define LASSO_LIB_STATUS_CODE_UNSUPPORTED_PROFILE          "lib:UnsupportedProfile"
 
 /* ProtocolProfile */
+
+/**
+ * LASSO_LIB_PROTOCOL_PROFILE_BRWS_ART:
+ *
+ * Identifies the Single Sign-On "Artifact" profile; where an artifact is
+ * passed from identity provider to service provider and back to get the
+ * #LassoLibAssertion.
+ */
 #define LASSO_LIB_PROTOCOL_PROFILE_BRWS_ART	\
 	"http://projectliberty.org/profiles/brws-art"
+
+/**
+ * LASSO_LIB_PROTOCOL_PROFILE_BRWS_POST:
+ *
+ * Identifies the Single Sign-On "POST" profile; where the #LassoLibAssertion
+ * is sent directly from the identity provider to the service provider in an
+ * HTML form submission message.
+ */
 #define LASSO_LIB_PROTOCOL_PROFILE_BRWS_POST	\
 	"http://projectliberty.org/profiles/brws-post"
+
 #define LASSO_LIB_PROTOCOL_PROFILE_BRWS_LECP	\
 	"http://projectliberty.org/profiles/lecp"
 #define LASSO_LIB_PROTOCOL_PROFILE_FED_TERM_IDP_HTTP	\
@@ -130,8 +185,28 @@
 #define LASSO_LIB_PROTOCOL_PROFILE_SLO_IDP_SOAP "http://projectliberty.org/profiles/slo-idp-soap"
 
 /* NameIdentifier formats */
+
+/**
+ * LASSO_LIB_NAME_IDENTIFIER_FORMAT_FEDERATED:
+ *
+ * <emphasis>Federated</emphasis> name identifier constant, used in
+ * #LassoNameIdentifier.  It implies the name identifier belongs to
+ * a federation established between SP and IdP.
+ */
 #define LASSO_LIB_NAME_IDENTIFIER_FORMAT_FEDERATED "urn:liberty:iff:nameid:federated"
+
+/**
+ * LASSO_LIB_NAME_IDENTIFIER_FORMAT_ONE_TIME:
+ *
+ * "One-time" name identifier constant, used in #LassoNameIdentifier.
+ */
 #define LASSO_LIB_NAME_IDENTIFIER_FORMAT_ONE_TIME  "urn:liberty:iff:nameid:one-time"
+
+/**
+ * LASSO_LIB_NAME_IDENTIFIER_FORMAT_ENCRYPTED:
+ *
+ * "Encrypted" name identifier constant, used in #LassoNameIdentifier.
+ */
 #define LASSO_LIB_NAME_IDENTIFIER_FORMAT_ENCRYPTED "urn:liberty:iff:nameid:encrypted"
 #define LASSO_LIB_NAME_IDENTIFIER_FORMAT_ENTITYID  "urn:liberty:iff:nameid:entityID"
 
@@ -210,7 +285,6 @@
 #define LASSO_DST_STATUS_CODE_DATA_TOO_LONG "DataTooLong"
 #define LASSO_DST_STATUS_CODE_EXISTS_ALREADY "ExistsAlready"
 #define LASSO_DST_STATUS_CODE_EXTENSION_NOT_SUPPORTED "ExtensionNotSupported"
-#define LASSO_DST_STATUS_CODE_FAILED "Failed"
 #define LASSO_DST_STATUS_CODE_INVALID_DATA "InvalidData"
 #define LASSO_DST_STATUS_CODE_INVALID_RESOURCE_ID "InvalidResourceID"
 #define LASSO_DST_STATUS_CODE_INVALID_SELECT "InvalidSelect"
@@ -364,6 +438,14 @@
 /* Name Identifier Format */
 
 /* note that SAML 2.0 can also use SAML 1.1 name identifier formats */
+#define LASSO_SAML2_NAME_IDENTIFIER_FORMAT_UNSPECIFIED \
+		"urn:oasis:names:tc:SAML:1.1:nameid-format:unspecified"
+#define LASSO_SAML2_NAME_IDENTIFIER_FORMAT_EMAIL \
+		"urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
+#define LASSO_SAML2_NAME_IDENTIFIER_FORMAT_X509 \
+		"urn:oasis:names:tc:SAML:1.1:nameid-format:X509SubjectName"
+#define LASSO_SAML2_NAME_IDENTIFIER_FORMAT_WINDOWS \
+		"urn:oasis:names:tc:SAML:1.1:nameid-format:WindowsDomainQualifiedName"
 #define LASSO_SAML2_NAME_IDENTIFIER_FORMAT_KERBEROS \
 		"urn:oasis:names:tc:SAML:2.0:nameid-format:kerberos"
 #define LASSO_SAML2_NAME_IDENTIFIER_FORMAT_ENTITY \
@@ -378,7 +460,7 @@
 /* Attribute Name */
 #define LASSO_SAML2_ATTRIBUTE_NAME_EPR "urn:liberty:disco:2006-08:DiscoveryEPR"
 
-/* Attribute Name Format*/
+/* Attribute Name Format */
 #define LASSO_SAML2_ATTRIBUTE_NAME_FORMAT_URI "urn:oasis:names:tc:SAML:2.0:attrname-format:uri"
 
 /* Consent */
@@ -495,12 +577,6 @@
 #define LASSO_IDWSF2_DISCO_HREF   "urn:liberty:disco:2006-08"
 #define LASSO_IDWSF2_DISCO_PREFIX "disco"
 
-#define LASSO_EP_HREF   "urn:liberty:id-sis-ep:2003-08"
-#define LASSO_EP_PREFIX "ep"
-
-#define LASSO_PP_HREF   "urn:liberty:id-sis-pp:2003-08"
-#define LASSO_PP_PREFIX "pp"
-
 #define LASSO_IDWSF2_DST_HREF "urn:liberty:dst:2006-08"
 #define LASSO_IDWSF2_DST_PREFIX "dst"
 
